spacepy.empiricals.getVampolaOrder — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »

# spacepy.empiricals.getVampolaOrder

`spacepy.empiricals.` `getVampolaOrder`(L)

  Empirical lookup of power for sin^n pitch angle model from Vampola (1996)

  Vampola, A.L. Outer zone energetic electron environment update, Final Report of ESA/ESTEC/WMA/P.O. 151351, ESA-ESTEC, Noordwijk, The Netherlands, 1996.

  Parameters: | L : arraylike or float
  Returns: | order : array coefficient for sin^n model corresponding to McIlwain L (computed for OP77?)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »